//
//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//  N o t e b o o k   H a r d w a r e   C o n t r o l   A C P I   D L L
//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//  Example class only
//
//  It is recommended to use a c# editor which supports c# syntax highlighting
//  and supports the directive #region and #endregion. With these directives
//  the source code is much more readable and it is easy to hide or show block 
//  of code (for example you can use the c# editor "SharpDevelop 2.0").
//
public static class EXAMPLE
{

    #region Computer model : class MODEL
    //
    public static class MODEL
    {

        #region Example class for LCD Brightness control (special class) : class BRIGHTNESS
        //
        // The class must have the name BRIGHTNESS
        //
        public static class BRIGHTNESS
        {
            // Default constants for the class
            public const string description = "LCD Brightness Control";             // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 1;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon, 5 = Temperature icon

            // Constants for the brightness control only (NHC will need this constants)
            public const int minimum_brightness_level = 0;
            public const int maximum_brightness_level = 15;
            public const int brightness_level_step = 1;

            // Value class for brightness_level (it must have the name BRIGHTNESS_LEVEL)
            public static class BRIGHTNESS_LEVEL
            {
                // Properties of the value class
                public const string description = "Current LCD brightness level";   // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int brightness_level = 0;                             // It must have the same name as the class (case are ignored)
            }

            // Function to set the brightness (it must have the name set_brightness)
            public static bool set_brightness(int new_level)
            {
                bool result = false;
                /* do something */
                return result;
            }

            // Function to get and refresh the brightness level (it must have the name set_brightness)
            public static bool get_brightness(ref int level)
            {
                bool result = false;
                /* do something */
                return result;
            }
        }
        //
        #endregion

        #region Example class for Hardware control (common class) : class HARDWARE
        //
        public static class HARDWARE
        {
            // Default constants for the hardware class
            public const string description = "Hardware class";                     // Description of current class
            public const bool default_enable = true;                                // true = By default the current class is enabled in NHC
            public const int icon = 0;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon, 5 = Temperature icon

            // Condition variables (optional)
            public static bool initialisation = false;                              // Initialisation variable: on initialisation NHC will set this variable to true; after the initialisation NHC will set this variabel to false
            public static bool enable = false;                                      // If NHC or the user enable the class the value is true otherwise the value is false

            #region  Value class for the example_value : class EXAMPLE_VALUE
            //
            public static class EXAMPLE_VALUE
            {
                // Properties of the value class
                public const string description = "value";                          // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value
                public static int example_value = 0;                                // It must have the same name as the class (case are ignored)
                public const string unit = "OFF|ON";                                // unit of the example_value class.
                // If the class NHC_WRITE is available, nhc_minimum_value = 0 and nhc_maximum_value = 1 then
                // the unit value "OFF|ON" is interpreted as "OFF" for the value 0 and "ON" for the value 1

                // With this optional class it is possible to change the value in NHC on runtime
                public static class NHC_WRITE
                {
                    public const bool nhc_write = true;                             // true -> it is possible to change the value in NHC
                    public const int nhc_minimum_value = 0;                         // the minimum value of example_value
                    public const int nhc_maximum_value = 1;                         // the maximum value of example_value
                    public const int nhc_default_value = 1;                         // the default value of example_value
                    public static bool nhc_on_write()                               // optional function - NHC will call this function if the user change the value on runtime and on NHC start
                    {
                        bool result = false;
                        if (example_value == 0)
                        {
                            /* do something */
                            // turn off the WLAN
                            return result;
                        }
                        else
                        {
                            /* do something */
                            // turn on the WLAN
                            return result;
                        }
                    }
                }
            }
            //
            #endregion

            // optional init function -> NHC will call this function on initialisation (after the nhc_on_write() functions)
            public static bool init()
            {
                bool result = false;
                /* do something */
                return result;
            }

            // optional close function -> NHC will call this function on NHC exit or if the user disable the class
            public static bool close()
            {
                bool result = false;
                /* do something */
                return result;
            }

            // optional refresh function -> NHC will call this function in the time interval which is defined in refresh_interval
            public const int refresh_interval = 1;                               	// <= 1 -> 1 Second; 2 -> 2 Seconds ...
            public static bool refresh()
            {
                bool result = false;
                /* do something */
                return result;
            }

            // optional highspeed refresh function -> NHC will call this function in the time interval which is defined in highspeed_refresh_interval            
            public const int highspeed_refresh_interval = 1;                        // <= 1 -> 1 millisecond; 2 -> 2 millisecond ...
            public static bool highspeed_refresh()
            {
                // N O T E !
                // - in the highspeed_refresh() function is no debugging information available
                // - the maximum resolution of the highspeed_refresh() function is 25ms to 50ms (the resolution depends from operating system and hardware)
                 
                bool result = false;
                /* do something */
                return result;
            }
        }
        //
        #endregion

        #region Example class for a custom Thermal Zone (thermal zone class) : class TZ00
        //
        public static class TZ00    // If the name of the Thermal Zone class is the same as the name of an existing thermal zone in the system then NHC will overwrite the system thermal zone
        {
            // Info
            public const string description = "CPU Temperature";                    // Description of current class
            public const bool default_enable = true;                                // false = By default the current class is disabled in NHC
            public const int icon = 5;                                              // 0 = Hardware icon, 1 = Brightness icon, 2 = Fan icon, 3 = Battery icon, 4 = Audio icon, 5 = Temperature icon
            public const bool thermal_zone = true;                                  // NHC will interpret this class as a Thermal Zone zone class if this value is true

            #region Value class for _TMP : class _TMP
            // 
            public static class _TMP                                                // If the name of the class is _TMP, then NHC can display this value in the NHC status and taskbar
            {
                // Properties of the value class
                public const string description = "Current Temperature";            // Description of current value
                public const bool nhc_visible = true;                               // true -> value is visible in NHC

                // Value                
                public static int _tmp = 0;                                         // It must have the same name as the class (case are ignored)
                public const string unit = "C";                                    // unit of the example_value class.                
            }
            //
            #endregion
            
            // Example code only ...
            public const int refresh_interval = 1;                                  // <= 1 -> 1 Second; 2 -> 2 Seconds ...
            public static bool refresh()
            {
                _TMP._tmp = _TMP._tmp + 1;
                if (_TMP._tmp > 100)
                {
                    _TMP._tmp = 0;
                }
            }
        }
        //
        #endregion

    }
    //
    #endregion

}
